@@ -5,24 +5,29 @@ dlmodeler.filter.KFAS <-
 		function(yt, model, raw.result=FALSE, logLik=TRUE, filter=TRUE)
 {
 	if(!require('KFAS')) stop("required package could not be found: KFAS")
-	res <- KFAS::kf(yt=yt,Zt=model$Zt,Tt=model$Tt,
-			Rt=model$Rt,Ht=model$Ht,Qt=model$Qt,
-			a1=model$a0,P1=model$P0,P1inf=model$P0inf,
-			optcal=c(FALSE,FALSE,FALSE,FALSE))
+	
+	# KFAS uses ts-class representation of the time series, 
+	# so each row consists of one time step, hence the transpose
+	kfas.model<-KFAS::SSModel(y=t(yt),Z=model$Zt,T=model$Tt,
+			R=model$Rt,H=model$Ht,Q=model$Qt,
+			a1=model$a0,P1=model$P0,P1inf=model$P0inf)
+	res<-KFAS::KFS(kfas.model,smoothing="none") # just filtering
+
 	if( raw.result ) raw.res <- res else raw.res <- NA
 	if( length(dim(model$Zt))==2 ) {
 		# 1-step ahead prediction when observation matrix is not time-varying
-		f <- res$Zt %*% res$at
+		f <- kfas.model$Z[,,1] %*% res$a
 	} else {
 		# 1-step ahead prediction when observation matrix is time-varying
-		f <- matrix(NA,NROW(res$Zt),NCOL(yt))
-		for( i in 1:NCOL(yt) ) f[,i] <- res$Zt[,,i] %*% res$at[,i]
+		f <- matrix(NA,NROW(res$model$Z),NCOL(yt))
+		for( i in 1:NCOL(yt) ) f[,i] <- res$model$Z[,,i] %*% res$a[,i]
 	}
+	
 	return(list(backend='KFAS',
 					f=f,
-					at=res$at,
-					Pt=res$Pt,
-					logLik=res$lik,
+					at=res$a,
+					Pt=res$P,
+					logLik=res$logLik,
 					d=res$d,
 					raw.result=raw.res))
 }
@@ -33,11 +38,14 @@ dlmodeler.smooth.KFAS <-
 		function(filt, raw.result=FALSE)
 {
 	if(!require('KFAS')) stop("required package could not be found: KFAS")
-	res <- KFAS::ks(filt$raw.result)
+	
+	res <- KFAS::KFS(filt$raw.result,smoothing="state") # same function, now smoothing
+	
 	if( raw.result ) raw.res <- res else raw.res <- NA
+	
 	return(list(backend='KFAS',
-					at=res$ahat,
-					Pt=res$Vt,
+					at=res$alphahat,
+					Pt=res$V,
 					raw.result=raw.res))
 }
 
